==> oozie-4.3.0.tar.gz: oozie-4.3.0/core/src/main/java/org/apache/oozie/executor/jpa/BundleJobInsertJPAExecutor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.oozie.executor.jpa;

import javax.persistence.EntityManager;

import org.apache.oozie.BundleJobBean;
import org.apache.oozie.util.ParamChecker;

/**
 * Persist the BundleJob bean.
 */
public class BundleJobInsertJPAExecutor implements JPAExecutor<String> {

    private BundleJobBean bundleJob = null;

    public BundleJobInsertJPAExecutor(BundleJobBean bundleJob) {
        ParamChecker.notNull(bundleJob, "bundleJob");
        this.bundleJob = bundleJob;
    }

    /* (non-Javadoc)
     * @see org.apache.oozie.executor.jpa.JPAExecutor#execute(javax.persistence.EntityManager)
     */
    @Override
    public String execute(EntityManager em) throws JPAExecutorException {
        em.persist(this.bundleJob);
        return null;
    }

    /* (non-Javadoc)
     * @see org.apache.oozie.executor.jpa.JPAExecutor#getName()
     */
    @Override
    public String getName() {
        return "BundleJobInsertJPAExecutor";
    }
}

==> oozie-5.2.1.tar.gz: oozie-5.2.1/core/src/main/java/org/apache/oozie/executor/jpa/BundleJobInsertJPAExecutor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.oozie.executor.jpa;

import javax.persistence.EntityManager;

import org.apache.oozie.BundleJobBean;

import java.util.Objects;

/**
 * Persist the BundleJob bean.
 */
public class BundleJobInsertJPAExecutor implements JPAExecutor<String> {

    private BundleJobBean bundleJob = null;

    public BundleJobInsertJPAExecutor(BundleJobBean bundleJob) {
        this.bundleJob = Objects.requireNonNull(bundleJob, "bundleJob cannot be null");
    }

    @Override
    public String execute(EntityManager em) throws JPAExecutorException {
        em.persist(this.bundleJob);
        return null;
    }

    @Override
    public String getName() {
        return "BundleJobInsertJPAExecutor";
    }
}
